@@ -6,7 +6,7 @@ the Software are granted under this license.
 
 The Clear BSD License
 
-Copyright (c) 2018-2024, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVdeC Authors.
+Copyright (c) 2018-2025, Fraunhofer-Gesellschaft zur Förderung der angewandten Forschung e.V. & The VVdeC Authors.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -52,6 +52,8 @@ POSSIBILITY OF SUCH DAMAGE.
 #define VVDEC_NAMESPACE_BEGIN
 #define VVDEC_NAMESPACE_END
 
+#define VVDEC_USE_UNSTABLE_API 0
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -64,6 +66,8 @@ VVDEC_NAMESPACE_BEGIN
 # define VVDEC_ARCH_ARM 1
 #elif defined( __wasm__ ) || defined( __wasm32__ )
 # define VVDEC_ARCH_WASM 1
+#elif defined( __loongarch__ )
+# define VVDEC_ARCH_LOONGARCH 1
 #endif
 
 /* vvdecDecoder:
@@ -149,6 +153,9 @@ typedef enum
 #elif defined( VVDEC_ARCH_WASM )
   VVDEC_SIMD_WASM     = 3,
   VVDEC_SIMD_MAX      = VVDEC_SIMD_WASM
+#elif defined( VVDEC_ARCH_LOONGARCH )
+  VVDEC_SIMD_LSX      = 3,
+  VVDEC_SIMD_MAX      = VVDEC_SIMD_LSX
 #else
   VVDEC_SIMD_SIMDE_ANY= 3,
   VVDEC_SIMD_MAX      = VVDEC_SIMD_SIMDE_ANY
@@ -282,6 +289,12 @@ typedef struct vvdecAccessUnit
   bool            ctsValid;            // composition time stamp valid flag (true: valid, false: CTS not set)
   bool            dtsValid;            // decoding time stamp valid flag (true: valid, false: DTS not set)
   bool            rap;                 // random access point flag (true: AU is random access point, false: sequential access)
+#if VVDEC_USE_UNSTABLE_API
+  void*           userData;            // user data to be returned in corresponding output YUV buffer
+  void*           reservedPtr_1;       // ...
+  int64_t         reserved_1;          // ...
+  int64_t         reserved_2;          // ...
+#endif
 } vvdecAccessUnit;
 
 /* vvdec_accessUnit_alloc:
@@ -395,7 +408,9 @@ typedef struct vvdecSeqInfo
 
   void*    reservedPtr_1;              // reserved space for future use
   void*    reservedPtr_2;              // ...
-  int64_t  reserved_1;                 // ...
+  uint32_t maxLatencyIncreasePlus1;    // max latency increase plus 1 across all temporal layers
+  uint8_t  maxNumReorderPics;          // max reorder pics across all temporal layers
+  int8_t   reserved_1[3];              // reserved (maintains 8-byte alignment)
   int64_t  reserved_2;                 // ...
 } vvdecSeqInfo;
 
@@ -415,8 +430,7 @@ typedef struct vvdecPicAttributes
   vvdecOlsHrd*      olsHrd;            // if available, pointer to OLS HRD (Output Layer Set Hypothetical Reference Decoder)
   vvdecSeqInfo*     seqInfo;           // if available, pointer to some data extracted from the SPS (Sequence Parameter Set)
   vvdecPicHashError picHashError;      // result of the decoded picture hash verification if enabled
-
-  void*             reservedPtr_1;     // reserved space for future use
+  void*             userData;          // user data for private data that is attached on the input vvdecAccessUnit with same cts
   void*             reservedPtr_2;     // ...
   int64_t           reserved_1;        // ...
   int64_t           reserved_2;        // ...
